@@ -1,4 +1,4 @@
-from .pdfrw import *
+import pdfrw
 from pdf2image import convert_from_path # Needs conda install -c conda-forge poppler
 from PIL import Image
 from collections import OrderedDict
